A character vector of the default flow type identifiers used by pocketlogR. These are not enforced — any string is accepted as a type. They exist for documentation, consistency, and convenience.
A character vector of the default flow type identifiers used by pocketlogR. These are not enforced — any string is accepted as a type. They exist for documentation, consistency, and convenience.